==> splitty-1.0.25.tgz: package/_editor/actions/fileaction.js <==
var FileAction = (function(){
    var self = {};
    var fileRegex = /\w\.\w/gi;
    function renderOpenFiles(){
         var ctx = {};
        ctx.files = FileUtils.getOpenedFiles();
        Template.render(ctx,"template-footer","fileList");
        editor.focus();
    }
    
    Events.when(FileUtils.events.FILE_OPEN, renderOpenFiles);
    Events.when(FileUtils.events.FILE_CLOSE, renderOpenFiles);
    Events.when(FileUtils.events.FILE_DIRTY, renderOpenFiles);
    
   
    
    self.openSelectedFile = function(file)  {
        if(file.startsWith("/")){
            FileUtils.open(file);
        }else{
            FileUtils.open("/"+file)
        }
        
    };
    
    self.execute = function(value)  {
     fileRegex.lastIndex = 0;  
     if(fileRegex.exec(value) !== null){
        self.openSelectedFile(value);
     }
      else {
         if (value.length && value.charAt(value.length - 1) != "/"){
            EditorUI.setActionText(value+"/");
         }
         self.findFiles();
         return 1;
      }
         
    }; 
    var typingTimer;
    var doneTypingInterval = 800;
    self.onkeyup = function(value) {
        clearTimeout(typingTimer);
        typingTimer = setTimeout(self.findFiles,doneTypingInterval);
    };
    
    self.findFiles = function() {
        var value = EditorUI.actionBoxValue();
        if(value === "") return;
        Shell.find(value, function(founds)  {
            var ctx = {};
            ctx.files = [];
            founds.each(function(elem,i){
                var obj = {};
                obj.name = elem.split("/").last();
                obj.path = elem;
                ctx.files.push(obj);
            });
            EditorUI.renderOutputAction(ctx,"template-found-files");
        });
    };
    
    self.init = function(txtValue) { txtValue.value = ""};
        
    self.getLabelAction = function(){ return "open"};
    
    self.executeAction = function(e , value)  {
        var nextEl = document.querySelector('[tabindex="'+(parseInt(e.target.getAttribute("tabindex")) + 1)+'"]');
        var nextPrev = document.querySelector('[tabindex="'+(parseInt(e.target.getAttribute("tabindex")) - 1)+'"]');
        var exec =  e.keyCode == 13 && EditorUI.onEnterOption(value);
        exec = exec || (e.keyCode == 40 && nextEl && nextEl.focus()) || (e.keyCode == 38 && nextPrev && nextPrev.focus());
        return exec;        
    };
    
    self.startup = function(){
        var appParams = Splitty.params();
        if(typeof(appParams.openFile) === "undefined") return;
        const fileToOpen = appParams.openFile;
        ProportionAction.execute("0");
        self.openSelectedFile(fileToOpen);
    };
        
    
    Shortcut.bindEvent("open",{mac:"Command+Shift-O", win:"Ctrl+Shift-O"},self);
    
    
    Shortcut.bindEvent("open next",{mac:"Option-Left", win:"Alt-Left"},{
        action:function() {
            FileUtils.openByIndex(FileUtils.currentFileIndex());
        }
    });
    Shortcut.bindEvent("open previous",{mac:"Option-Right", win:"Alt-Right"},{
        action:function(){
            FileUtils.openByIndex(FileUtils.currentFileIndex() + 2);
        }
    });
    
    Shortcut.bindEvent("save file",{mac:"Command+S", win:"Ctrl+S"},{
        action:function(){
           FileUtils.save();
        }
    });
    
    Shortcut.bindEvent("close file",{mac:"Option+Shift-Q", win:"Alt+Shift-Q"},{
        action:function(){
           FileUtils.close();
        }
    });

    self.mkdir = function(name,callback)  {
        Shell.send("mkdir",{"name":name},callback);        
    };

    self.delete = function(name,callback)  {
        Shell.send("rm",{"name":name},callback);
    };

    self.deleteRecursive = function(name,callback)  {
        Shell.send("rmRec",{"name":name},callback);
    };

    self.createFile = function(name,callback) {
       self.touch(name,callback);
    };

    self.touch = function(name,callback)  {
        Shell.send("touch",{"name":name},callback);
    };

    self.renameFile = function(name,oldName,callback) {
        Shell.send("rename",{"name":name, "oldName":oldName},callback);        
    };

    self.mv = function(from,to,callback) {
        Shell.send("mv",{"from":from, "to":to},callback);        
    };

    
    Splitty.register(self);
    return self;
})();

==> splitty-1.0.28.tgz: package/_editor/actions/fileaction.js <==
var FileAction = (function(){
    var self = {};
    var fileRegex = /\w\.\w/gi;
    function renderOpenFiles(){
         var ctx = {};
        ctx.files = FileUtils.getOpenedFiles();
        Template.render(ctx,"template-footer","fileList");
        editor.focus();
    }
    
    Events.when(FileUtils.events.FILE_OPEN, renderOpenFiles);
    Events.when(FileUtils.events.FILE_CLOSE, renderOpenFiles);
    Events.when(FileUtils.events.FILE_DIRTY, renderOpenFiles);
    
   
    
    self.openSelectedFile = function(file)  {
        if(file.startsWith(Splitty.delimiter())){
            FileUtils.open(file);
        }else{
            FileUtils.open(Splitty.delimiter()+file)
        }
        
    };
    
    self.execute = function(value)  {
     fileRegex.lastIndex = 0;  
     if(fileRegex.exec(value) !== null){
        self.openSelectedFile(value);
     }
      else {
         if (value.length && value.charAt(value.length - 1) != Splitty.delimiter()){
            EditorUI.setActionText(value+Splitty.delimiter());
         }
         self.findFiles();
         return 1;
      }
         
    }; 
    var typingTimer;
    var doneTypingInterval = 800;
    self.onkeyup = function(value) {
        clearTimeout(typingTimer);
        typingTimer = setTimeout(self.findFiles,doneTypingInterval);
    };
    
    self.findFiles = function() {
        var value = EditorUI.actionBoxValue();
        if(value === "") return;
        Shell.find(value, function(founds)  {
            var ctx = {};
            ctx.files = [];
            founds.each(function(elem,i){
                var obj = {};
                obj.name = elem.split(Splitty.delimiter()).last();
                obj.path = elem;
                ctx.files.push(obj);
            });
            EditorUI.renderOutputAction(ctx,"template-found-files");
        });
    };
    
    self.init = function(txtValue) { txtValue.value = ""};
        
    self.getLabelAction = function(){ return "open"};
    
    self.executeAction = function(e , value)  {
        var nextEl = document.querySelector('[tabindex="'+(parseInt(e.target.getAttribute("tabindex")) + 1)+'"]');
        var nextPrev = document.querySelector('[tabindex="'+(parseInt(e.target.getAttribute("tabindex")) - 1)+'"]');
        var exec =  e.keyCode == 13 && EditorUI.onEnterOption(value);
        exec = exec || (e.keyCode == 40 && nextEl && nextEl.focus()) || (e.keyCode == 38 && nextPrev && nextPrev.focus());
        return exec;        
    };
    
    self.startup = function(){
        var appParams = Splitty.params();
        if(typeof(appParams.openFile) === "undefined") return;
        const fileToOpen = appParams.openFile;
        ProportionAction.execute("0");
        self.openSelectedFile(fileToOpen);
    };
        
    
    Shortcut.bindEvent("open",{mac:"Command+Shift-O", win:"Ctrl+Shift-O"},self);
    
    
    Shortcut.bindEvent("open next",{mac:"Option-Left", win:"Alt-Left"},{
        action:function() {
            FileUtils.openByIndex(FileUtils.currentFileIndex());
        }
    });
    Shortcut.bindEvent("open previous",{mac:"Option-Right", win:"Alt-Right"},{
        action:function(){
            FileUtils.openByIndex(FileUtils.currentFileIndex() + 2);
        }
    });
    
    Shortcut.bindEvent("save file",{mac:"Command+S", win:"Ctrl+S"},{
        action:function(){
           FileUtils.save();
        }
    });
    
    Shortcut.bindEvent("close file",{mac:"Option+Shift-Q", win:"Alt+Shift-Q"},{
        action:function(){
           FileUtils.close();
        }
    });

    self.mkdir = function(name,callback)  {
        Shell.send("mkdir",{"name":name},callback);        
    };

    self.delete = function(name,callback)  {
        Shell.send("rm",{"name":name},callback);
    };

    self.deleteRecursive = function(name,callback)  {
        Shell.send("rmRec",{"name":name},callback);
    };

    self.createFile = function(name,callback) {
       self.touch(name,callback);
    };

    self.touch = function(name,callback)  {
        Shell.send("touch",{"name":name},callback);
    };

    self.renameFile = function(name,oldName,callback) {
        Shell.send("rename",{"name":name, "oldName":oldName},callback);        
    };

    self.mv = function(from,to,callback) {
        Shell.send("mv",{"from":from, "to":to},callback);        
    };

    
    Splitty.register(self);
    return self;
})();
